<?php     defined('C5_EXECUTE') or die("Access Denied.");

/**
 * ab_two_gis_maps package for Concrete5
 * Copyright Copyright 2017-2018, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_two_gis_maps
 */
 
$al = $app->make('helper/concrete/asset_library');

$pkg = \Concrete\Core\Package\Package::getByHandle('ab_two_gis_maps');
$imgURL = $pkg->getRelativePath() . '/blocks/ab_two_gis_maps/images/';

?>

<style>
.ab-two-gis-map-form .text-muted {
    font-size: 0.8em;
}

.ab-two-gis-map-form .spinner-img {
    display: inline-block;
    margin-left: 20px;
}

.ab-two-gis-map-form .spinner-img img {
    border: none !important;
    display: inline-block;
    width: 30px;
    height: 30px;
}

.ab-two-gis-map-form #spinner_list, .ab-two-gis-map-form #spinner_point {
    margin-left: 20px;
    display: inline-block;
}
</style>

<fieldset class="ab-two-gis-map-form">

    <div class="col-xs-12">
        <div class="form-group">
            <div id="block_note" class="alert alert-info" role="alert">
            <?php echo t('Click on map to set location'); ?>
            </div>             
            <div id="two_gis_map" style="height: 300px; width: auto;"></div>
        </div>
    </div>
        
    <div class="col-xs-12">
        <div class="form-group">
            <?php 
            echo $form->label('location', t('Enter location'));
            echo $form->text('location', $location, ['maxlength' => 200]);
            echo '<p class="text-muted">' . t('Max 200 symbols') . '</p>';
            ?>
        </div>
    </div>

    <div class="col-xs-12">
        <div class="form-group">
            <div class="checkbox" data-checkbox-wrapper="show_geocoding">
                <label>
                    <?php
                    echo $form->checkbox('show_geocoding', 1, $show_geocoding);
                    echo t('Use geocoding to search for location on map?');
                    ?>
                </label>
            </div>
            <div data-fields="show_geocoding" style="display: none">
                <div class="well">
                    <div class="form-group">
                        <?php
                        echo $form->label('api_key', t('LocationIQ API Key'));
                        echo $form->text('api_key', $api_key ? $api_key : '', ['maxlength' => 20]);
                        echo '<p class="text-muted">' . t('Max 20 symbols') . t(' (obtain API key at ') . '<a href="https://locationiq.org/pricing" target="_blank">LocationIQ.org</a>)' . '</p>';
                        ?>
                    </div>
                    <div class="form-group">
                        <?php
                        echo $form->label('server', t('Choose closest server location'));
                        echo $form->select('server', $servers, $server_selected);
                        ?>
                    </div>
                    <div class="form-group">
                        <?php
                        echo $form->button('search', t('Search'), array('style' => 'width: 125px;'), 'btn-primary');
                        echo '<div id="spinner_img" class="spinner-img hidden">';
                        echo '<img src="' . $imgURL . 'spinner.gif" />';
                        echo '</div>';
                        echo '<span id="spinner_list" class="text-primary hidden">' . t('Searching locations...') . '</span>';
                        echo '<span id="spinner_point" class="text-primary hidden">' . t('Searching coordinates...') . '</span>';
                        ?>
                    </div>
                    <div class="form-group">
                        <?php
                        echo $form->label('locations', t('Choose location'));
                        echo $form->select('locations', null, null);
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
        
    <div class="col-xs-6">
        <div class="form-group">
            <?php
            echo $form->label('latitude', t('Location latitude'));
            echo $form->text('latitude', $latitude ? $latitude : "55.753994", ['maxlength' => 20, 'class' => "decimals"]);
            echo '<p class="text-muted">' . t('Max 20 symbols, numeric only') . '</p>';
            ?>
        </div>
    </div>

    <div class="col-xs-6">
        <div class="form-group">
            <?php
            echo $form->label('longitude', t('Location longitude'));
            echo $form->text('longitude', $longitude ? $longitude : "37.622093", ['maxlength' => 20, 'class' => "decimals"]);
            echo '<p class="text-muted">' . t('Max 20 symbols, numeric only') . '</p>';
            ?>
        </div>
    </div>
    
    <div class="col-xs-6">
        <div class="form-group">
            <label class="control-label" for="height" name="height">
            <?php echo t('Map height'); ?>
            <i class="launch-tooltip fa fa-question-circle" title="<?php echo h(t('Set map height with \'px\' or \'%\' only')); ?>"></i>
            </label>
            <div class="input-group">
            <span class="input-group-addon"><i class="fa fa-arrows-v"></i></span>
            <?php echo $form->text('height', $height ? $height : "300px", ['maxlength' => 6]); ?>
            </div>
            <?php echo '<p class="text-muted">' . t('Max 6 symbols') . '</p>'; ?>
        </div>
    </div>

    <div class="col-xs-6">
        <div class="form-group">
            <label class="control-label" for="width" name="width">
            <?php echo t('Map width'); ?>
            <i class="launch-tooltip fa fa-question-circle" title="<?php echo h(t('Set map width with \'px\' or \'%\' only')); ?>"></i>
            </label>
            <div class="input-group">
            <span class="input-group-addon"><i class="fa fa-arrows-h"></i></span>
            <?php echo $form->text('width', $width ? $width : "100%", ['maxlength' => 6]); ?>
            </div>
            <?php echo '<p class="text-muted">' . t('Max 6 symbols') . '</p>'; ?>
        </div>
    </div>

    <div class="col-xs-6">
        <div class="form-group">
            <?php
            echo $form->label('zoom', t('Map zoom'));
            echo $form->number('zoom', $zoom ? $zoom : "12", ['min' => '1', 'max' => '16', 'class' => "decimals"]);
            echo '<p class="text-muted">' . t('Values from 1 to 16') . '</p>';
            ?>
        </div>
    </div>
    
    <div class="col-xs-12">
        <div class="form-group">
            <div class="checkbox">
                <label>
                    <?php
                    echo $form->checkbox('lock_wheel', 1, $lock_wheel);
                    echo t('Enable mouse wheel zoom over map?');
                    ?>
                </label>
            </div>
        </div>
    </div>
    
    <div class="col-xs-12">
        <div class="form-group">
            <div id="block_note" class="alert alert-info" role="alert">
            <?php echo t('Define info to show on map balloon and hint'); ?>
            </div>             
        </div>
    </div>
        
    <div class="col-xs-12">
        <div class="form-group">
            <div class="checkbox" data-checkbox-wrapper="show_name">
                <label>
                    <?php
                    echo $form->checkbox('show_name', 1, $show_name);
                    echo t('Show name at location?');
                    ?>
                </label>
            </div>
            <div data-fields="show_name" style="display: none">
                <div class="well">
                    <div class="form-group">
                        <?php
                        echo $form->label('name', t('Location name'));
                        echo $form->text('name', $name, ['maxlength' => 100]);
                        echo '<p class="text-muted">' . t('Max 100 symbols') . '</p>';
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
        
    <div class="col-xs-12">
        <div class="form-group">
            <div class="checkbox" data-checkbox-wrapper="show_address">
                <label>
                    <?php
                    echo $form->checkbox('show_address', 1, $show_address);
                    echo t('Show alternative address at location?');
                    ?>
                </label>
            </div>
            <div data-fields="show_address" style="display: none">
                <div class="well">
                    <div class="form-group">
                        <?php
                        echo $form->label('address', t('Alternative location address'));
                        echo $form->text('address', $address, ['maxlength' => 100]);
                        echo '<p class="text-muted">' . t('Max 100 symbols') . '</p>';
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
        
    <div class="col-xs-12">
        <div class="form-group">
            <div class="checkbox" data-checkbox-wrapper="show_tel">
                <label>
                    <?php
                    echo $form->checkbox('show_tel', 1, $show_tel);
                    echo t('Show telephone at location?');
                    ?>
                </label>
            </div>
            <div data-fields="show_tel" style="display: none">
                <div class="well">
                    <div class="form-group">
                        <?php
                        echo $form->label('tel', t('Telephone'));
                        echo $form->text('tel', $tel, ['maxlength' => 100]);
                        echo '<p class="text-muted">' . t('Max 100 symbols') . '</p>';
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="col-xs-12">
        <div class="form-group">
            <div class="checkbox" data-checkbox-wrapper="show_email">
                <label>
                    <?php
                    echo $form->checkbox('show_email', 1, $show_email);
                    echo t('Show email at location?');
                    ?>
                </label>
            </div>
            <div data-fields="show_email" style="display: none">
                <div class="well">
                    <div class="form-group">
                        <?php
                        echo $form->label('email', t('Email'));
                        echo $form->text('email', $email, ['maxlength' => 100]);
                        echo '<p class="text-muted">' . t('Max 100 symbols') . '</p>';
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="col-xs-12">
        <div class="form-group">
            <div class="checkbox" data-checkbox-wrapper="show_picture">
                <label>
                    <?php
                    echo $form->checkbox('show_picture', 1, $show_picture);
                    echo t('Show picture at location?');
                    ?>
                </label>
            </div>
            <div data-fields="show_picture" style="display: none">
                <div class="well">
                    <div class="form-group">
                        <?php
                        echo $form->label('picture', t('Picture'));
                        echo $al->image('picture', 'pictureID', t('Choose picture'), $pic);
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

</fieldset>

<script type="text/javascript">
$(function(){
    loadScript('https://maps.api.2gis.ru/2.0/loader.js?pkg=full&skin=light', function(){
        DG.then(function() {
            init();
        });
    });
    
    $('.decimals').keydown(function (e) {
        // Allow: backspace, delete, tab, escape, enter and .
        if ($.inArray(e.keyCode, [46, 8, 9, 27, 13, 110, 190]) !== -1 ||
             // Allow: Ctrl+A, Command+A
            (e.keyCode === 65 && (e.ctrlKey === true || e.metaKey === true)) || 
             // Allow: home, end, left, right, down, up
            (e.keyCode >= 35 && e.keyCode <= 40)) {
                 // let it happen, don't do anything
                 return;
        }
        // Ensure that it is a number and stop the keypress
        if ((e.shiftKey || (e.keyCode < 48 || e.keyCode > 57)) && (e.keyCode < 96 || e.keyCode > 105)) {
            e.preventDefault();
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Oops')); ?>,
                message: <?php echo json_encode(t('Numbers only!')); ?>
            });
        }
    });

    $('#ccm-form-submit-button').on('click', function(e){
        var location = $.trim($('#location').val());
        if (location == '') {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Location value error:')); ?>,
                message: <?php echo json_encode(t('Location cannot be empty')); ?>
            });
        }
        
        var latitude = $.trim($('#latitude').val());
        var longitude = $.trim($('#longitude').val());
        if (latitude == '' || longitude == '') {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Coordinates value error:')); ?>,
                message: <?php echo json_encode(t('Coordinates cannot be empty')); ?>
            });
        }
        
        var zoom = parseInt($.trim($('#zoom').val()));
        if (zoom < 1 || zoom > 16) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Zoom value error:')); ?>,
                message: <?php echo json_encode(t('Zoom values can be from 1 to 16')); ?>
            });
        }
        
        var height = $.trim($('#height').val());
        var width = $.trim($('#width').val());
        var regex = /(\d)(px|%)$/;
        if (height == '' || !regex.test(height) || width == '' || !regex.test(width)) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Map height/width value error:')); ?>,
                message: <?php echo json_encode(t('Map height/width values cannot be empty and must end with with \'px\' or \'%\'')); ?>
            });
        }
        
        var email = $.trim($('#email').val());
        var regex = /^([_a-zA-Z0-9-]+)(\.[_a-zA-Z0-9-]+)*@([a-zA-Z0-9-]+)(\.[a-zA-Z0-9-]+)*(\.[a-zA-Z]{2,10})$/;
        if (email != '' && !regex.test(email)) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Email value error:')); ?>,
                message: <?php echo json_encode(t('Email address is not valid')); ?>
            });
        }
        
    });
    
    $('#search').on('click', function(e){
        var location = $.trim($('#location').val());
        var api_key = $.trim($('#api_key').val());
        var server = $.trim($('#server').val());
        
        location = location.replace(/\s/g,"%20");
        if (location != '') {
            var settings = {
            "async": true,
            "crossDomain": true,
            "url": "https://" + server + ".unwiredlabs.com/v2/search.php?token=" + api_key + "&q=" + location + "&format=json&accept-language=<?php echo t('en'); ?>",
            "method": "GET",
            }
            
            $('#spinner_img').removeClass("hidden");
            $('#spinner_list').removeClass("hidden");
            $.ajax(settings)
            .done(function(response) {
                $('#spinner_img').addClass("hidden");
                $('#spinner_list').addClass("hidden");
                if (response['status'] === "ok") {
                    $('#locations').empty();
                    $('#locations').append($("<option/>").val(0).text('<?php echo t('Select address'); ?>'));
                    $.each(response['address'], function(i, v) {
                        $('#locations').append($("<option/>").val(i+1).text(v['display_name']));
                    });
                }
                else if (response['status'] === "error"){
                    $('#locations').empty();
                    ConcreteAlert.error({
                        title: <?php echo json_encode(t('Geocoding error:')); ?>,
                        message: response['message']
                    });
                }
            })
            .fail(function(jqXHR, textStatus, errorThrown) {
                $('#spinner_img').addClass("hidden");
                $('#spinner_list').addClass("hidden");
                ConcreteAlert.error({
                    title: <?php echo json_encode(t('Geocoding failure:')); ?>,
                    message: errorThrown
                });
            });
        }
    });

    $('#locations').on('change', function(e){
        var location = $('#locations option:selected').text();
        var api_key = $.trim($('#api_key').val());
        var server = $.trim($('#server').val());
        
        location = location.replace(/\s/g,"%20");
        if (location != '') {
            var settings = {
            "async": true,
            "crossDomain": true,
            "url": "https://" + server + ".unwiredlabs.com/v2/search.php?token=" + api_key + "&q=" + location + "&format=json&accept-language=<?php echo t('en'); ?>",
            "method": "GET",
            }
            
            $('#spinner_img').removeClass("hidden");
            $('#spinner_point').removeClass("hidden");
            $.ajax(settings)
            .done(function(response) {
                $('#spinner_img').addClass("hidden");
                $('#spinner_point').addClass("hidden");
                if (response['status'] === "ok") {
                    $('#latitude').val(response['address'][0]['lat']);
                    $('#longitude').val(response['address'][0]['lon']);
                }
                else if (response['status'] === "error"){
                    ConcreteAlert.error({
                        title: <?php echo json_encode(t('Geocoding error:')); ?>,
                        message: response['message']
                    });
                }
            })
            .fail(function(jqXHR, textStatus, errorThrown) {
                $('#spinner_img').addClass("hidden");
                $('#spinner_point').addClass("hidden");
                ConcreteAlert.error({
                    title: <?php echo json_encode(t('Geocoding failure:')); ?>,
                    message: errorThrown
                });
            });
        }
    });

    $('#show_geocoding').on('change', function() {
        $('div[data-fields=show_geocoding]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#api_key').val('');
            $('#locations').empty();
        }
    }).trigger('change');

    $('#show_name').on('change', function() {
        $('div[data-fields=show_name]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#name').val('');
        }
    }).trigger('change');

    $('#show_address').on('change', function() {
        $('div[data-fields=show_address]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#address').val('');
        }
    }).trigger('change');

    $('#show_tel').on('change', function() {
        $('div[data-fields=show_tel]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#tel').val('');
        }
    }).trigger('change');

    $('#show_email').on('change', function() {
        $('div[data-fields=show_email]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#email').val('');
        }
    }).trigger('change');

    $('#show_picture').on('change', function() {
        $('div[data-fields=show_picture]').toggle($(this).is(':checked'));
    }).trigger('change');

});

function loadScript(url, callback){
    var script = document.createElement('script');
    script.type = 'text/javascript';
    script.setAttribute('src', url);

    script.onreadystatechange = callback;
    script.onload = callback;

    var head = document.getElementsByTagName('head')[0];
    head.appendChild(script, head);
};
    
function init() {
    var myMap, myPopUp, myPlacemark;
    
    myMap = DG.map('two_gis_map', {
        'center': [<?php echo $latitude; ?>, <?php echo $longitude; ?>],
        'zoom': <?php echo $zoom ? $zoom : '12'; ?>,
        geoclicker: false,
    });
    myMap.setLang('<?php echo t('en'); ?>');

    DG.control.location({position: 'bottomright'}).addTo(myMap);

    myPlacemark = DG.marker([<?php echo $latitude; ?>, <?php echo $longitude; ?>], {
        draggable: true
    });
    myPlacemark.addTo(myMap);
    myPlacemark.bindLabel($('#location').val(), {
        static: true,
    });
    myPlacemark.on('click', function(e) {
        myMap.setView([e.latlng.lat, e.latlng.lng]);
    });
    myPlacemark.on('drag', function(e) {
        $('#latitude').val(e.latlng.lat);
        $('#longitude').val(e.latlng.lng);
    });
    
    myMap.on('click', function(e) {
        var lat = e.latlng.lat;
        var lng = e.latlng.lng;
        myPlacemark.setLatLng([lat, lng]);
        getAddress();
        getName(lat, lng);
    });
    
    function getAddress() {
        myPlacemark.unbindLabel();
    };

    function getName(lat, lng) {
        var api_key = $.trim($('#api_key').val());
        var server = $.trim($('#server').val());
        
        if (lat != '' && lng != '') {
            var settings = {
            "async": true,
            "crossDomain": true,
            "url": "https://" + server + ".unwiredlabs.com/v2/reverse.php?token=" + api_key + "&lat=" + lat + "&lon=" + lng + "&format=json&accept-language=<?php echo t('en'); ?>",
            "method": "GET",
            }
            
            $('#spinner_img').removeClass("hidden");
            $('#spinner_point').removeClass("hidden");
            $.ajax(settings)
            .done(function(response) {console.log(response);
                $('#spinner_img').addClass("hidden");
                $('#spinner_point').addClass("hidden");
                if (response['status'] === "ok") {
                    $('#location').val(response['address']['display_name']);
                    myPlacemark.bindLabel(response['address']['display_name'], {
                        static: true,
                    });
                }
                else if (response['status'] === "error"){
                    ConcreteAlert.error({
                        title: <?php echo json_encode(t('Geocoding error:')); ?>,
                        message: response['message']
                    });
                }
            })
            .fail(function(jqXHR, textStatus, errorThrown) {
                $('#spinner_img').addClass("hidden");
                $('#spinner_point').addClass("hidden");
                ConcreteAlert.error({
                    title: <?php echo json_encode(t('Geocoding failure:')); ?>,
                    message: errorThrown
                });
            });
        }
    };

};

</script>
